@@ -1,8 +1,9 @@
 from .processing import (
-    cdi_curve_2_surface,
+    CDICurve2Surface,
     calculator,
     coordinate_transformation_widget,
-    edge_detection_widget,
 )
 from .contours import ContourValues
 from .em_profiling import EMLineProfiler
+from .edge_detection import EdgeDetectionApp
+from .data_interpolation import DataInterpolation
